@@ -83,3 +83,32 @@ sub BinarySafeBLOBs {
 }
 
 # }}}
+
+=head2 ApplyLimits STATEMENTREF ROWS_PER_PAGE FIRST_ROW
+
+takes an SQL SELECT statement and massages it to return ROWS_PER_PAGE starting with FIRST_ROW;
+
+
+=cut
+
+sub ApplyLimits {
+    my $self = shift;
+    my $statementref = shift;
+    my $per_page = shift;
+    my $first = shift;
+
+    my $limit_clause = '';
+
+    if ( $per_page) {
+        $limit_clause = " LIMIT ";
+        $limit_clause .= $per_page;
+        if ( $first != 0 ) {
+            $limit_clause .= " OFFSET $first";
+        }
+    }
+
+   $$statementref .= $limit_clause; 
+
+}
+
+
